# pytest-quarantine

[![PyPI version](https://img.shields.io/pypi/v/pytest-quarantine.svg)](https://pypi.org/project/pytest-quarantine)
[![Python versions](https://img.shields.io/pypi/pyversions/pytest-quarantine.svg)](https://pypi.org/project/pytest-quarantine)
[![Linux build status](https://img.shields.io/travis/com/bhrutledge/pytest-quarantine?logo=travis)](https://travis-ci.com/bhrutledge/pytest-quarantine)
[![Windows build status](https://img.shields.io/appveyor/ci/bhrutledge/pytest-quarantine?logo=appveyor)](https://ci.appveyor.com/project/bhrutledge/pytest-quarantine)
[![Test coverage](https://img.shields.io/codecov/c/github/bhrutledge/pytest-quarantine?logo=codecov)](https://codecov.io/gh/bhrutledge/pytest-quarantine)

A plugin for [pytest](https://github.com/pytest-dev/pytest) to manage expected test failures.

## Features

- TODO

## Requirements

- TODO

## Installation

Via [pip](https://pypi.org/project/pip/) from [PyPI](https://pypi.org/project/pytest-quarantine):

```
$ pip install pytest-quarantine
```

## Usage

- TODO

## Getting help

Please submit questions, bug reports, and feature requests in the [issue tracker](https://github.com/bhrutledge/pytest-quarantine/issues).

## Contributing

Improvements to the code and documentation are greatly appreciated. See [How to contribute](https://github.com/bhrutledge/pytest-quarantine/blob/master/CONTRIBUTING.md) for details.

## Code of conduct

Everyone interacting with this project is expected to follow the [Contributor Covenant](https://github.com/bhrutledge/pytest-quarantine/blob/master/CODE_OF_CONDUCT.md).

## License

Distributed under the terms of the [MIT](http://opensource.org/licenses/MIT) license.

## Acknowledgements

This project was initially generated with [Cookiecutter](https://github.com/audreyr/cookiecutter) using the [cookiecutter-pytest-plugin](https://github.com/pytest-dev/cookiecutter-pytest-plugin) template. The layout and tooling has been heavily modified since then, but it was very helpful to start.
